#!/bin/sh

######################################Header Information
# check_fou4s v0.1
# by William R. Jacqmein // Mitsubishi Chemical America
# based on check_yum v0.6
#
# REQUIREMENTS:
# Install fou4s from http://fou4s.gaugusch.at/index.shtml

PATH=/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin
PROGNAME=`basename $0`
PROGPATH=`echo $0 | sed -e 's,[\\/][^\\/][^\\/]*$,,'`
REVISION=`echo '$Revision: 1.2 $' | sed -e 's/[^0-9.]//g'`
FOU4S=/usr/sbin/fou4s

print_revision(){
       echo $1 $2
}

print_usage() {
	echo "Usage: $PROGNAME [host]"
}

print_help() {
	print_revision $PROGNAME $REVISION
	echo
	print_usage
	echo "Will check with fou4s is see if a SuSE install is update-to-date with the latest"
	echo "patches. The only parameter that is supported, is a host name that is contacted"
	echo "via ssh. You can also use the user@host scheme." 
	echo
	exit 0
}

check_host() {
	if [ -n "$1" ] ; then 
		updates=`ssh "$1" "$FOU4S -e --nocolor | grep 'update.s., total' | awk '{print \\\$1;}'"`
	else
		updates=`/usr/sbin/fou4s -e --nocolor | grep "update.s., total" | awk '{print $1;}'`
	fi
	ret=$?
	if [[ -z $updates ]] && [[ $ret -eq 0 ]] ; then
		echo "FOU4S OK - System is up-to-date"
		exit 0
	elif [[ $updates != [0-9]* ]] ; then
		 echo "FOU4S WARNING - Unknown error!"
		 exit 1
	elif [ $updates -gt 1 ] ; then
		 echo "FOU4S CRITICAL - $updates packages need to be updated!"
		 exit 2
	elif [ $updates -gt 0 ] ; then
		 echo "FOU4S CRITICAL - $updates package needs to be updated!"
		 exit 2
	else
		 echo "FOU4S WARNING - Unknown error!"
		 exit 1
	fi
}

case "$1" in
	--help|-h)
		print_help
		exit 0
		;;
	--version|-V)
		print_revision $PROGNAME $REVISION
		exit 0
		;;
	*)
		check_host "$1"
		;;
esac
